pythran: Ahead of Time compiler for numeric kernels
===================================================

Description
-----------

Ahead of Time compiler for numeric kernels

License
-------

BSD 3-Clause

Upstream Contact
----------------

https://pypi.org/project/pythran/

